# GenSchedulingCuda-GSC

El objetivo de este proyecto es desarrollar una libreria que permita resolver diversos problemas de planeación de producción de manera flexible y rápida por medio de modulos que el usuario pueda configurar y unir para crear sus propias implementaciones; cada módulo se implenta en cuda y corren directamente en la GPU con ayuda de las librerias numba y cupy, lo que grarantiza una ejecución en paralelo y tiempos de espera mucho menores que si la ejecución se hiciese en CPU.

![Estrutura](https://github.com/mandalarotation/GenSchedulingCuda-GSC/blob/master/estrucutra%20gsc.png)

# Desarrolladores

Jean Carlo Jimenez Giraldo  Estudiante Ingenieria Industrial Universidad Nacional de Colombia Sede Medellín

Elkin Rodriguez Velasquez Profesor Ingenieria Industrial Universidad Nacional de Colombia Sede Medellín

Yubar Daniel Marin Benjumea Estadistica Universidad Nacional de Colombia Sede Medellín


